Enum TncMode Copy item path Source pub enum TncMode {
Aprs = 0,
Navitra = 1,
Kiss = 2,
Mmdvm = 3,
}Expand description TNC operating mode.
Controls the built-in TNC’s protocol mode. Used by the TN CAT command.
The second field of TN is the data speed (0=1200, 1=9600).
Source: firmware validation (mode < 4), Operating Tips 2.7-2.8 (KISS),
4.5 (Reflector Terminal/MMDVM), firmware string table (NAVITRA).
APRS mode — standard packet operation (index 0).
NAVITRA mode — Japanese APRS variant (index 1).
KISS mode — PC-based packet via KISS protocol (index 2).
Enter with TN 2,0 (Band A) or TN 2,1 (Band B).
See Operating Tips 2.7, User Manual Chapter 15.
The built-in TNC has 4 KB TX and RX buffers and supports only
KISS mode (no Command mode or Converse mode).
MMDVM/Reflector Terminal mode — D-STAR reflector access (index 3).
Uses MMDVM serial commands via USB or Bluetooth.
See Operating Tips 4.5.
Number of valid TNC mode values (0-3).
Performs copy-assignment from
source.
Read more Formats the value using the given formatter.
Read more Formats the value using the given formatter.
Read more Converts to this type from the input type.
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
The type returned in the event of a conversion error.
Performs the conversion.
Immutably borrows from an owned value.
Read more Mutably borrows from an owned value.
Read more 🔬 This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more Returns the argument unchanged.
Instruments this type with the provided [
Span], returning an
Instrumented wrapper.
Read more Calls U::from(self).
That is, this conversion is whatever the implementation of
From <T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more Uses borrowed data to replace owned data, usually by cloning.
Read more Converts the given value to a
String.
Read more The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.